from setuptools import setup

setup(
    name='Abinde',
    version='2.2',
    install_requires=[
        'pygame>=2.1.2',
        'importlib-metadata; python_version >= "3.8"',
        'pillow',
    ],
    url="https://github.com/Abinde-Game-Dev",
    author="_TheRealPenguin",
    keywords="game python lightweight open-source raspberry-pi mac linux games image game-engine simple game-development game-2d pygame help-wanted easy-to-use easy open-source-project good-first-issue pygame-games pygame-game",
    license="MIT",
    description="Abinde is an easy-to-use python module for pygame.",
    classifiers=[
	    "Development Status :: 2 - Pre-Alpha",
	    "License :: OSI Approved :: MIT License",
	    "Natural Language :: English",
	    "Programming Language :: Python :: 3 :: Only",
	    "Topic :: Games/Entertainment",
	    "Topic :: Utilities",
	    "Intended Audience :: Developers",
    ]
)
